@@ -4,7 +4,7 @@ from json import loads
 import click
 from cryptography.fernet import Fernet
 
-from examtool.api import set_exam, get_exam, set_roster
+from examtool.api.database import set_exam, get_exam, set_roster
 from examtool.cli.utils import exam_name_option
 
 
@@ -13,16 +13,14 @@ from examtool.cli.utils import exam_name_option
 @click.option(
     "--json",
     prompt=True,
-    default="data/exams/sample_exam.json",
     type=click.File("r"),
-    help="The json JSON you wish to deploy.",
+    help="The exam JSON you wish to deploy.",
 )
 @click.option(
     "--roster",
     prompt=True,
-    default="data/rosters/sample_roster.csv",
     type=click.File("r"),
-    help="The json roster you wish to deploy.",
+    help="The roster CSV you wish to deploy.",
 )
 @click.option(
     "--default-deadline",
@@ -42,19 +40,19 @@ def deploy(exam, json, roster, default_deadline):
     json = loads(json)
 
     json["default_deadline"] = default_deadline
-    json["secret"] = Fernet.generate_key()
+    json["secret"] = Fernet.generate_key().decode("utf-8")
 
     try:
-        json["secret"] = get_exam(exam)["secret"]
+        json["secret"] = get_exam(exam=exam)["secret"]
     except (TypeError, KeyError):
         pass
 
-    set_exam(exam, json)
+    set_exam(exam=exam, json=json)
 
     next(roster)  # ditch headers
-    set_roster(exam, roster)
+    set_roster(exam=exam, roster=list(roster))
 
-    print("Exam uploaded with password:", json["secret"][:-1].decode("utf-8"))
+    print("Exam uploaded with password:", json["secret"][:-1])
 
 
 if __name__ == "__main__":
