@@ -1,12 +1,13 @@
 import csv
 import json
 import os
+import pathlib
 
 import click
 from fpdf import FPDF
 
-from examtool.api import get_exam, get_submissions
-from examtool.api import scramble
+from examtool.api.database import get_exam, get_submissions
+from examtool.api.scramble import scramble
 from examtool.cli.utils import exam_name_option, hidden_output_folder_option
 
 
@@ -21,14 +22,13 @@ def download(exam, out, name_question, sid_question):
     Exams are downloaded as PDFs into a target folder - specify `out` to redirect the folder.
     An `OUTLINE.pdf` is also generated for Gradescope, as is a `summary.csv` for analytics or autograding.
     """
-    exam_json = get_exam(exam)
+    exam_json = get_exam(exam=exam)
     exam_json.pop("secret")
     exam_json = json.dumps(exam_json)
 
     out = out or "out/export/" + exam
 
-    if not os.path.exists(out):
-        os.mkdir(out)
+    pathlib.Path(out).mkdir(parents=True, exist_ok=True)
 
     pdf = FPDF()
     pdf.add_page()
@@ -48,7 +48,7 @@ def download(exam, out, name_question, sid_question):
 
     total = [["Email"] + [question["text"] for question in extract_questions(json.loads(exam_json))]]
 
-    for email, response in get_submissions(exam):
+    for email, response in get_submissions(exam=exam):
         if 1 < len(response) < 10:
             print(email, response)
 
